/*
  Macro           Test_Color_Descriptions
  Author          Carlo Hogeveen
  Website         ecarlo.nl/tse
  Compatibility   Tested with GUI TSE 4.50 rc5
  Version         1.0.1   27 Jun 2023

  This tool generates and executes a helper tool, that lists all 288 possible
  Color() descriptions, prefixed by the color number that Color() returns.

  It turns out Color() only returns the color numbers 0 - 255.
  Who would have thought!

  Sorting the generated buffer reveals which color descriptions describe
  a same color.


  HISTORY

  v1       27 Jun 2023
    Initial release.

  v1.0.1   27 Jun 2023
    The helper source file was erroneously named with a .mac extension, which
    without any problem was compiled to the exact same name, with the end
    result that the saved helper source did not exist any more.
*/

string  COLOR_NAMES     [46] = 'Black;Blue;Green;Cyan;Red;Magenta;Yellow;White'
string  COLOR_MODIFIERS [30] = ';Intense;Bright;Intense Bright'
#define DOS_SYNC_CALL_FLAGS _DONT_PROMPT_|_DONT_CLEAR_|_START_HIDDEN_|_RETURN_CODE_

proc Main()
  string  background_color_name  [7] = 'Magenta'
  integer background_color_nr        = 0
  integer color_modifier_nr          = 0
  string  color_modifier_text   [14] = ''
  string  combined_color_name   [18] = 'Magenta on Magenta'
  string  foreground_color_name  [7] = 'Magenta'
  integer foreground_color_nr        = 0
  string  full_color_name       [33] = 'Intense Bright Magenta on Magenta'
  string  full_color_syntax     [40] = 'Color(Intense Bright Magenta on Magenta)'
  string  helper_macro         [255] = ''

  NewFile() // Helper macro
  AddLine('proc main()')
  AddLine('  NewFile()')
  // AddLine('  AddLine("Color    Color")')
  // AddLine('  AddLine("Number   Name")')
  for foreground_color_nr = 1 to NumTokens(COLOR_NAMES, ';')
    foreground_color_name = GetToken(COLOR_NAMES, ';', foreground_color_nr)
    for background_color_nr = 0 to NumTokens(COLOR_NAMES, ';')
      background_color_name = GetToken(COLOR_NAMES, ';', background_color_nr)
      combined_color_name = Format(foreground_color_name,
                                   iif(background_color_name == '',
                                       '',
                                       ' on ' + background_color_name))
      for color_modifier_nr = 1 to NumTokens(COLOR_MODIFIERS, ';')
        color_modifier_text = GetToken(COLOR_MODIFIERS, ';', color_modifier_nr)
        full_color_name     = Trim(Format(color_modifier_text;
                                          combined_color_name))
        full_color_syntax   = 'Color(' + full_color_name + ')'
        AddLine(Format('  AddLine(Format(', full_color_syntax, ':6;;;"',
                       full_color_name, '"))'))
      endfor
    endfor
  endfor
  AddLine('  PurgeMacro(CurrMacroFilename())')
  AddLine('end Main')
  helper_macro = SplitPath(CurrMacroFilename(), _DRIVE_|_PATH_|_NAME_) +
                 '_helper.s'
  ChangeCurrFilename(helper_macro, _DONT_PROMPT_|_DONT_EXPAND_|_OVERWRITE_)
  if SaveAs(helper_macro, _DONT_PROMPT_|_OVERWRITE_)
    lDos(QuotePath(SplitPath(LoadDir(TRUE), _DRIVE_|_PATH_) + 'sc32'),
         QuotePath(helper_macro),
         DOS_SYNC_CALL_FLAGS)
    // No compilation errors  -> lDos = 0, DosIOResult = 0.
    // Only compiler warnings -> lDos = 1, DosIOResult = 1.
    // Compilation errors!    -> lDos = 1, DosIOResult = 2.
    if (DosIOResult() in 0, 1)
      if ExecMacro(SplitPath(helper_macro, _NAME_))
        BegFile()
      else
        Warn('Failed executing helper macro "',
             SplitPath(helper_macro, _NAME_), '".')
      endif
    else
      Warn('Compile errors in helper macro "', helper_macro, '".')
    endif
  endif
  PurgeMacro(CurrMacroFilename())
end

